
package require Tcl 8.4

namespace eval ::Imago {
  variable thisScriptFilename [file normalize [info script]]
  variable imagoScriptDir [file dirname $thisScriptFilename]
}

source [file join $::Imago::imagoScriptDir "imago-common.tcl"]

set imago_config [::Imago::load_config]

::Imago::set_config_value aaa "workspace" "my workspace"

set workspace [::Imago::get_config_value imago_config "workspace"]
set dataset [::Imago::get_config_value imago_config "dataset"]
set imagery_group_type [::Imago::get_config_value imago_config "imagery_group_type"]
set imagery_type [::Imago::get_config_value imago_config "imagery_type"]
set core_tray_mesh_folder_path [::Imago::get_config_value imago_config "core_tray_mesh_folder_path"]
set linear_mesh_folder_path [::Imago::get_config_value imago_config "linear_mesh_folder_path"]
set mesh_database_file_path [::Imago::get_config_value imago_config "mesh_database_file_path"]

# GuidoForm Example 3
# Define the form and store into a Tcl variable called formDef
set formDef {
  GuidoForm aForm {
    -label "Imago Configuration"
    -help_url SSI_PROFILES:imago/resource/scripts/readme.pdf

    GuidoField workspace {
      -label "Workspace"
      -width 11
      -null true
    }

    GuidoField dataset {
      -label "Dataset"
      -width 11
      -null true
    }

    GuidoField imagery_group_type {
      -label "Imagery Group Type"
      -width 11
      -null false
    }

    GuidoField imagery_type {
      -label "Imagery Type"
      -width 11
      -null false
    }

    GuidoFileBrowserField mesh_database_file_path {
      -label "Mesh Database"
      -width 20
      -absolutePath true
      -file_mask "*.mdb" "*.accdb"
      -extension true
    }

    GuidoFileBrowserField core_tray_mesh_folder_path {
      -label "Core Tray Mesh Folder"
      -width 20
      -browser_type directory
      -absolutePath true
    }

    GuidoFileBrowserField linear_mesh_folder_path {
      -label "Linear Mesh Folder"
      -width 20
      -browser_type directory
      -absolutePath true
    }

    -default_buttons "Save" "Cancel"
  }
}
# Create and run the form (note that the form definition was stored in the formDef variable above)
SclCreateGuidoForm formHandle $formDef {}
$formHandle SclRun {}

if { $_status == "apply" } {

  ::Imago::set_config_value imago_config "workspace" $workspace
  ::Imago::set_config_value imago_config "dataset" $dataset
  ::Imago::set_config_value imago_config "imagery_group_type" $imagery_group_type
  ::Imago::set_config_value imago_config "imagery_type" $imagery_type
  ::Imago::set_config_value imago_config "core_tray_mesh_folder_path" $core_tray_mesh_folder_path
  ::Imago::set_config_value imago_config "linear_mesh_folder_path" $linear_mesh_folder_path
  ::Imago::set_config_value imago_config "mesh_database_file_path" $mesh_database_file_path

  ::Imago::save_config imago_config
}


