
namespace eval ::Imago {
  variable thisScriptFilename [file normalize [info script]]
  variable imagoScriptDir [file dirname $thisScriptFilename]
}

source [file join $::Imago::imagoScriptDir "imago-common.tcl"]

set imago_config [::Imago::load_config]

set status [ SclFunction "CHECK DATABASE CONNECTED" {
  databasesession="GeologyDatabase"
  databasepurpose="drillholes"
  databasehandle="GEOLOGY"
}]

set keep_selecting 1
while { $keep_selecting } {
  set scl_result [SclDrillholeSelect "Choose a drillhole" "on" "collar" hole_id hole_depth]

  if { $scl_result > 0 } {

    if { [::Imago::confirm_mesh_type mesh_type "Select a mesh type for hole ${hole_id}:"] } {

      if { ![::Imago::mesh_exists $mesh_type $hole_id] } {
        set formatted_mesh_type [::Imago::format_mesh_type $mesh_type]
        ::Imago::display_warning "${formatted_mesh_type} Not Found" "${formatted_mesh_type} does not exist for hole ${hole_id} ([::Imago::get_hole_mesh_file_path $mesh_type $hole_id])"
      } else {

        puts "Opening [::Imago::format_mesh_type $mesh_type] for ${hole_id} ([::Imago::get_hole_mesh_file_path $mesh_type $hole_id]) ..."

        set mesh_file_path [::Imago::get_hole_mesh_file_path $mesh_type $hole_id]
        set layer_name [file tail [file rootname $mesh_file_path]]

        # Clean up existing layer for hole if it exists
        set layer_found_b 0
        sclGraphicsLayers SclIterateFirst itr_h
        while { [$itr_h SclIterateNext swa_h] == $::SCL_TRUE } {
          if { [string equal -nocase [$swa_h SclGetId] $layer_name] } {
            SclDestroy swa_h
          }
        }

        # Now recal file into new layer
        set status [ SclFunction "RECALL ANY FILE" {
          file="$mesh_file_path"
          mode="openInNewLayerNoRescale"
        }]

      }

    } else {
      set keep_selecting 0
    }

  } else {
    set keep_selecting 0
  }

}


